from __future__ import print_function, unicode_literals
from ..lib.handler.youtrack_handler import YoutrackHandler
from ..lib.handler.github_handler import GithubHandler
from ..lib.handler import git_handler as git
from ..lib.config import Config
from ..lib.logger import Logger
from ..lib.handler import prompt_utils

import re
import sys

youtrack = YoutrackHandler()
github = GithubHandler()
logger = Logger()
config = Config().load()


def entrypoint(args):
    git.is_dirty(args.project)

    try:
        if args.card:
            issue = youtrack.get_issue(args.card)
        else:
            issue = youtrack.get_issue(ask_card())
    except:
        logger.error("Si e' verificato un problema recuperando la issue da youtrack. Controlla che il numero della issue e' corretto")
        sys.exit(-1)

    checkout_branch(args.project, issue)

    youtrack.assign_to(issue["id"], "me")

    youtrack.update_state(issue["id"], config["youtrack"]["picked_state"])

def ask_card():
    return prompt_utils.ask_questions_input('Inserisci il numero della issue youtrack: ', "PRIMA-XXX")

def checkout_branch(project, issue):
    branch_name = prompt_utils.ask_questions_input("Inserisci nome del branch: ", re.sub(
        r'([\s\\.~\^:\[\]"\'?]|[^\x00-\x7F])+', "-", issue["summary"]
    ).lower())

    parent_branch_name = prompt_utils.ask_questions_input(
        "Inserisci branch iniziale: ", "master")

    branch_type = issue["Type"].lower().replace(" ", "-")

    branch_name = "{}/{}/{}".format(
        branch_type, branch_name, issue["id"]
    )

    git.checkout(project, parent_branch_name)

    git.checkout(project, branch_name)



from __future__ import print_function, unicode_literals
import marshal
import subprocess
import os
from PyInquirer import prompt
from .singleton import Singleton

TOKENS = ['github', 'youtrack', 'slack', 'drone']

class Tokens(metaclass=Singleton):
    _file_name = None
    _tokens = {}
    _changed = False

    def __init__(self, file_name=os.path.join(
            os.environ['HOME'], '.suite_py/tokens')):
        self._file_name = file_name
        try:
            self.load()
        except Exception:
            pass

        self.check()
        if self._changed:
            self.save()

    def load(self):
        with open(self._file_name, 'rb') as configfile:
            self._tokens = marshal.load(configfile)

    def check(self):
        for token in TOKENS:
            if not self._tokens.get(token):
                self._tokens[token] = prompt([{
                    'type': 'input',
                    'name': token,
                    'message': 'Insert your {} token:'.format(token.capitalize())
                }])[token]
                self._changed = True

    def save(self):
        with open(self._file_name, 'wb') as configfile:
            marshal.dump(self._tokens, configfile)

    @property
    def github(self):
        return self._tokens['github']

    @property
    def youtrack(self):
        return self._tokens['youtrack']

    @property
    def slack(self):
        return self._tokens['slack']

    @property
    def drone(self):
        return self._tokens['drone']



import sys
from autoupgrade import Package
from .__init__ import dispatch


def main():
    Package('suite_py', verbose=True).smartupgrade()
    return dispatch(sys.argv[1:])


if __name__ == "__main__":
    sys.exit(main())



from __future__ import print_function, unicode_literals
from ..lib.handler.youtrack_handler import YoutrackHandler
from ..lib.handler import git_handler as git
from ..lib.logger import Logger
from ..lib.qainit import qainit_shutdown

import sys

youtrack = YoutrackHandler()
logger = Logger()


def entrypoint(args):
    branch_name = git.current_branch_name()
    youtrack_id = youtrack.get_card_from_name(branch_name)

    logger.info("Spengo il qa se esite...")
    qainit_shutdown(branch_name)

    sys.exit()



from ..tokens import Tokens
import requests
import time

tokens = Tokens()
baseurl = "https://drone-1.prima.it"


def get_last_build_url(repo):
    # necessario per far comparire la build che abbiamo appena pushato
    time.sleep(2)
    try:
        resp = requests.get("{}/api/repos/primait/{}/builds".format(baseurl, repo),
                            headers={'Authorization': 'Bearer {}'.format(tokens.drone)}).json()

        return '{}/primait/{}/{}'.format(baseurl, repo, resp[0]['number'])
    except (Exception) as e:
        return ""


def get_pr_build_url(repo, commit_sha):
    try:
        resp = requests.get("{}/api/repos/primait/{}/builds".format(baseurl, repo),
                            headers={'Authorization': 'Bearer {}'.format(tokens.drone)}).json()
        build_number = list(filter(lambda build: build.after == commit_sha, resp))[
            0]['number']
        return '{}/primait/{}/{}'.format(baseurl, repo, build_number)
    except (Exception) as e:
        return ""
